@@ -63,7 +63,10 @@ class AssetEvent(Event):
         EventType.WORKFLOW_DELETED,
         EventType.CHATTY_AI_AGENT_DELETED,
         EventType.CHATTY_AI_AGENT_CREATED,
-        EventType.CHATTY_AI_AGENT_UPDATED
+        EventType.CHATTY_AI_AGENT_UPDATED,
+        EventType.COMPANY_CREATED,
+        EventType.COMPANY_UPDATED,
+        EventType.COMPANY_DELETED
     }
 
     @model_validator(mode='after')
