@@ -1,4 +1,5 @@
 from letschatty.models.utils.types import StrObjectId
+from letschatty.models.execution.execution import ExecutionContext
 from pydantic import BaseModel, Field
 from letschatty.models.utils.definitions import Area
 from letschatty.models.chat.quality_scoring import QualityScore
@@ -33,17 +34,23 @@ class FilterParameters(BaseModel):
     sales_date_range: Optional[tuple[datetime, datetime]] = Field(default=None)
     sources_date_range: Optional[tuple[datetime, datetime]] = Field(default=None)
     sent_templates : list[str] = Field(default=[])
+    executor_user_id: StrObjectId
+
+    @property
+    def is_my_chats(self) -> bool:
+        return len(self.agents) == 1 and self.agents[0] == self.executor_user_id and len(self.area_status) == 0
 
     @property
     def is_direct(self) -> bool:
-        if not self.search_in_chat and not self.search_like and not self.sent_templates and not self.products and not self.sales_products and not self.tags and not self.business_areas and not self.funnels and not self.funnel_stages and not self.time_since_last_message_hours and not self.sources and not self.quality_score and not self.messages_count and not self.workflows and not self.last_message_date_range and not self.sales_date_range and not self.sources_date_range and len(self.area_status) == 1 and len(self.agents) <= 1:
+        if not self.search_in_chat and not self.search_like and not self.sent_templates and not self.products and not self.sales_products and not self.tags and not self.business_areas and not self.funnels and not self.funnel_stages and not self.time_since_last_message_hours and not self.sources and not self.quality_score and not self.messages_count and not self.workflows and not self.last_message_date_range and not self.sales_date_range and not self.sources_date_range and len(self.area_status) <= 1 and (len(self.agents) <= 1 or self.is_my_chats):
             return True
         return False
 
     @classmethod
-    def from_query_params(cls, query_params: dict) -> "FilterParameters":
+    def from_query_params(cls, query_params: dict, execution_context: ExecutionContext) -> "FilterParameters":
         logger.debug(f"Query params: {query_params}")
         processed_params = {}
+        processed_params["executor_user_id"] = execution_context.executor.id
 
         # Handle all list fields
         list_fields = {
