@@ -1,6 +1,8 @@
+from zoneinfo import ZoneInfo
 from pydantic import BaseModel, Field
 from ..utils.types import StrObjectId
 from ..messages.chatty_messages import ChattyMessage
+from zoneinfo import ZoneInfo
 from datetime import datetime
 from .time_left import TimeLeft
 from .scheduled_messages import ScheduledMessageStatus
@@ -32,13 +34,21 @@ class ChatPreview(BaseModel):
     client : ClientPreview
     last_message : Optional[ChattyMessage]
     is_read_status : bool
-    free_conversation_time_left_seconds : float = Field(default=0)
-    free_template_window_time_left_seconds : float = Field(default=0)
+    free_conversation_expire_date : datetime
+    free_template_window_expire_date : datetime
     starred : bool
     created_at : datetime
     scheduled_message : Optional[ScheduledMessageStatus] = Field(default=None)
     tags : Optional[List[TagPreview]] = Field(default=[])
 
+    @property
+    def assigned_agent_id(self) -> Optional[StrObjectId]:
+        if self.area_status != Area.WITH_AGENT:
+            raise ValueError(f"Chat is not assigned to an agent: {self.chat_id} client: {self.client.name}")
+        if self.agent is None:
+            raise ValueError(f"Agent is not assigned to this chat: {self.chat_id} client: {self.client.name}")
+        return self.agent.id
+
     def last_message_old_format(self) -> dict:
         if self.last_message is None:
             return {
@@ -57,11 +67,11 @@ class ChatPreview(BaseModel):
     def model_dump(self) -> dict:
         dump = json.loads(super().model_dump_json())
         dump["last_message"] = self.last_message_old_format()
-        logger.debug(f"self.free_conversation_time_left_seconds: {self.free_conversation_time_left_seconds}")
-        logger.debug(f"self.free_template_window_time_left_seconds: {self.free_template_window_time_left_seconds}")
+        logger.debug(f"self.free_conversation_expire_date: {self.free_conversation_expire_date}")
+        logger.debug(f"self.free_template_window_expire_date: {self.free_template_window_expire_date}")
         dump["time_left"] = TimeLeft.get_time_left(
-            time_left_for_free_conversation_seconds=self.free_conversation_time_left_seconds,
-            time_left_for_free_template_window_seconds=self.free_template_window_time_left_seconds
+            time_left_for_free_conversation_seconds=(self.free_conversation_expire_date.replace(tzinfo=ZoneInfo("UTC")) - datetime.now(tz=ZoneInfo("UTC"))).total_seconds(),
+            time_left_for_free_template_window_seconds=(self.free_template_window_expire_date.replace(tzinfo=ZoneInfo("UTC")) - datetime.now(tz=ZoneInfo("UTC"))).total_seconds()
         ).model_dump()
         logger.debug(f"dump['time_left']: {dump['time_left']}")
         return dump
