@@ -17,11 +17,11 @@ class EmpresaModel(ChattyAssetModel):
     active: Optional[bool] = Field(default = True)
     friendly_aliases: list[str] = Field(description="The friendly aliases of the company used for the enviamewhats.app links", default_factory=lambda: [])
     terms_of_service_agreement: Optional[bool] = Field(default = False)
-    self_display_phone_number: Optional[str] = Field(description="The display phone number user's write to", default = None, alias="display_phone_number")
-    self_phone_number_id: Optional[str] = Field(description="The phone number id of the company", alias="phone_number_id", default = None)
-    self_bussiness_account_id: Optional[str] = Field(description="The WABA - WhatsApp Business Account id of the company", default = None, alias="bussiness_account_id")
+    display_phone_number: Optional[str] = Field(description="The display phone number user's write to", default = None, alias="display_phone_number")
+    phone_number_id: Optional[str] = Field(description="The phone number id of the company", alias="phone_number_id", default = None)
+    business_account_id: Optional[str] = Field(description="The WABA - WhatsApp Business Account id of the company", default = None, alias="bussiness_account_id")
     photo_url: str = Field(default = "")
-    self_meta_token: Optional[str] = Field(default = None, alias="meta_token")
+    meta_token: Optional[str] = Field(default = None, alias="meta_token")
     slack_channels: Dict[str,Dict[str,str]] = Field(default_factory=lambda:{})
     phone_numbers_for_testing: list[str] = Field(default_factory=lambda: [])
     analytics : Optional[bool] = Field(default = True)
@@ -51,21 +51,32 @@ class EmpresaModel(ChattyAssetModel):
         return self.continuous_conversation_template_name
 
     @property
-    def waba_id(self) -> str:
-        return self.bussiness_account_id
+    def waba_id_value(self) -> str:
+        if self.business_account_id is None:
+            raise ValueError(f"business_account_id is not set for company {self.name}")
+        return self.business_account_id
 
     @property
-    def database_name(self):
-        return "chatty-db"
+    def phone_number_id_value(self) -> str:
+        if self.phone_number_id is None:
+            raise ValueError(f"phone_number_id is not set for company {self.name}")
+        return self.phone_number_id
+
+    @property
+    def meta_token_value(self) -> str:
+        if self.meta_token is None:
+            raise ValueError(f"meta_token is not set for company {self.name}")
+        return self.meta_token
+
 
     @property
     def whatsapp_channel(self) -> WhatsAppClientInfo:
         if self.active_for_messaging:
             return WhatsAppClientInfo(
-                display_phone_number=self.display_phone_number,
-                business_phone_number_id=self.phone_number_id,
-                waba_id=self.bussiness_account_id,
-                access_token=SecretStr(self.meta_token),
+                display_phone_number=self.display_phone_number_value,
+                business_phone_number_id=self.phone_number_id_value,
+                waba_id=self.waba_id_value,
+                access_token=SecretStr(self.meta_token_value),
                 dataset_id=self.dataset_id
             )
         else:
@@ -76,36 +87,18 @@ class EmpresaModel(ChattyAssetModel):
         return self.friendly_aliases[0]
 
     @property
-    def display_phone_number(self):
-        if self.self_display_phone_number is None:
+    def display_phone_number_value(self):
+        if self.display_phone_number is None:
             raise ValueError(f"display_phone_number is not set for company {self.name}")
-        return self.self_display_phone_number
-
-    @property
-    def phone_number_id(self):
-        if self.self_phone_number_id is None:
-            raise ValueError(f"phone_number_id is not set for company {self.name}")
-        return self.self_phone_number_id
-
-    @property
-    def bussiness_account_id(self):
-        if self.self_bussiness_account_id is None:
-            raise ValueError(f"bussiness_account_id is not set for company {self.name}")
-        return self.self_bussiness_account_id
-
-    @property
-    def meta_token(self):
-        if self.self_meta_token is None:
-            raise ValueError(f"meta_token is not set for company {self.name}")
-        return self.self_meta_token
+        return self.display_phone_number
 
     @property
     def active_for_messaging(self) -> bool:
         try:
-            self.meta_token
-            self.phone_number_id
-            self.bussiness_account_id
-            self.display_phone_number
+            self.meta_token_value
+            self.phone_number_id_value
+            self.waba_id_value
+            self.display_phone_number_value
             return True
         except ValueError:
             return False
