@@ -55,7 +55,7 @@ class EventFactory:
 
         return CustomerEventData(
             company_phone_number_id=company_info.phone_number_id, #type: ignore
-            company_waba_id=company_info.waba_id,
+            company_waba_id=company_info.waba_id_value,
             chat_id=chat_with_assets.chat.id if chat_with_assets else None,
             client_phone_number=chat_with_assets.chat.client.get_waid() if chat_with_assets else None,
             client_email=chat_with_assets.chat.client.get_email() if chat_with_assets else None,
@@ -593,7 +593,7 @@ class EventFactory:
 
         user_data = UserEventData(
             company_phone_number_id=company_info.phone_number_id, #type: ignore
-            company_waba_id=company_info.waba_id, #type: ignore
+            company_waba_id=company_info.waba_id_value,
             user_id=user.id,
             executor_type=executor_type,
             executor_id=executor_id,
