@@ -46,7 +46,7 @@ class SourceFactory:
             )
 
     @staticmethod
-    def create_topic_default_source(topic: Topic, company_id: str) -> TopicDefaultSource:
+    def create_topic_default_source(topic: Topic, company_id: str, whatsapp_default_source: WhatsAppDefaultSource) -> TopicDefaultSource:
         return TopicDefaultSource(
             topic_id=topic.id,
             name = f"{topic.name} Topic Default Source",
@@ -54,7 +54,11 @@ class SourceFactory:
             description= "Message matched the Topic but there was no direct source to attribute it to.",
             created_at=topic.created_at,
             updated_at=topic.updated_at,
-            company_id=company_id
+            company_id=company_id,
+            flow=whatsapp_default_source.flow,
+            tags=whatsapp_default_source.tags,
+            products=whatsapp_default_source.products,
+            chatty_ai_agent_config=whatsapp_default_source.chatty_ai_agent_config
             )
 
     @staticmethod
