@@ -25,14 +25,14 @@ class ClientFactory:
         )
 
     @staticmethod
-    def from_filled_template_data(filled_template_data: FilledTemplateData, company_id: StrObjectId) -> Client:
-        country = ClientService.find_country_with_phone(filled_template_data.phone_number) #type: ignore
+    def from_phone_number_and_name(phone_number:str, new_contact_name:str, company_id: StrObjectId) -> Client:
+        country = ClientService.find_country_with_phone(phone_number)
         client : Client = Client(
-            waid = filled_template_data.phone_number, #type: ignore
-            name = filled_template_data.new_contact_name, #type: ignore
+            waid = phone_number,
+            name = new_contact_name,
             country = country,
             created_at=datetime.now(ZoneInfo("UTC")),
             updated_at=datetime.now(ZoneInfo("UTC")),
             company_id=company_id,
         )
-        return client
+        return client
\ No newline at end of file
